@@ -101,7 +101,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
             return self.load_scheduler_event(self.asset_id, event, max_lookback_seconds)
 
         if event_type == 'wits_stream':
-            return self.load_wits_stream_event(self.asset_id, event)
+            return self.load_wits_stream_event(self.asset_id, event, max_lookback_seconds)
 
         return None
 
